summaryrefslogtreecommitdiffstats
path: root/Modules
diff options
context:
space:
mode:
authorStefan Krah <skrah@bytereef.org>2013-05-29 19:12:46 (GMT)
committerStefan Krah <skrah@bytereef.org>2013-05-29 19:12:46 (GMT)
commitb6cc0aad4bb288494a8f8c9f2f501afc9573b910 (patch)
treef7d2d3b09e0760ad93c34b57f9977b78f59fa4e6 /Modules
parentf7b62a366ef002082f4d3be85f0728d26f06bc84 (diff)
parent04754b0fd49aa832b4358c3f3a9e95fbf0888404 (diff)
downloadcpython-b6cc0aad4bb288494a8f8c9f2f501afc9573b910.zip
cpython-b6cc0aad4bb288494a8f8c9f2f501afc9573b910.tar.gz
cpython-b6cc0aad4bb288494a8f8c9f2f501afc9573b910.tar.bz2
Merge 3.3.
Diffstat (limited to 'Modules')
-rwxr-xr-xModules/_decimal/tests/runall-memorydebugger.sh15
1 files changed, 8 insertions, 7 deletions
diff --git a/Modules/_decimal/tests/runall-memorydebugger.sh b/Modules/_decimal/tests/runall-memorydebugger.sh
index 44ff3b3..a446fc8 100755
--- a/Modules/_decimal/tests/runall-memorydebugger.sh
+++ b/Modules/_decimal/tests/runall-memorydebugger.sh
@@ -9,8 +9,9 @@
# Requirements: valgrind
#
# Set additional CFLAGS for ./configure
ADD_CFLAGS=
+ADD_LDFLAGS=
CONFIGS_64="x64 uint128 ansi64 universal"
@@ -74,7 +75,7 @@ for args in "--without-threads" ""; do
cd ../../
$GMAKE distclean > /dev/null 2>&1
- ./configure CFLAGS="$ADD_CFLAGS" --with-pydebug $args > /dev/null 2>&1
+ ./configure CFLAGS="$ADD_CFLAGS" LDFLAGS="$ADD_LDFLAGS" --with-pydebug $args > /dev/null 2>&1
$GMAKE | grep _decimal
printf "\n\n# ======================== refleak tests ===========================\n\n"
@@ -86,7 +87,7 @@ for args in "--without-threads" ""; do
printf "\nbuilding python ...\n\n"
$GMAKE distclean > /dev/null 2>&1
- ./configure CFLAGS="$ADD_CFLAGS" $args > /dev/null 2>&1
+ ./configure CFLAGS="$ADD_CFLAGS" LDFLAGS="$ADD_LDFLAGS" $args > /dev/null 2>&1
$GMAKE | grep _decimal
printf "\n\n# ======================== regular tests ===========================\n\n"
@@ -106,7 +107,7 @@ for args in "--without-threads" ""; do
print_config "valgrind tests: config=$config" $args
printf "\nbuilding python ...\n\n"
$GMAKE distclean > /dev/null 2>&1
- ./configure CFLAGS="$ADD_CFLAGS" --without-pymalloc $args > /dev/null 2>&1
+ ./configure CFLAGS="$ADD_CFLAGS" LDFLAGS="$ADD_LDFLAGS" --without-pymalloc $args > /dev/null 2>&1
$GMAKE | grep _decimal
printf "\n\n# ======================== valgrind tests ===========================\n\n"
@@ -132,7 +133,7 @@ for config in $CONFIGS; do
printf "\nbuilding python ...\n\n"
$GMAKE distclean > /dev/null 2>&1
- ./configure CFLAGS="$ADD_CFLAGS" --with-pydebug $args > /dev/null 2>&1
+ ./configure CFLAGS="$ADD_CFLAGS" LDFLAGS="$ADD_LDFLAGS" --with-pydebug $args > /dev/null 2>&1
$GMAKE | grep _decimal
printf "\n\n# ========================== debug ===========================\n\n"
@@ -143,7 +144,7 @@ for config in $CONFIGS; do
printf "\nbuilding python ...\n\n"
$GMAKE distclean > /dev/null 2>&1
- ./configure CFLAGS="$ADD_CFLAGS" $args > /dev/null 2>&1
+ ./configure CFLAGS="$ADD_CFLAGS" LDFLAGS="$ADD_LDFLAGS" $args > /dev/null 2>&1
$GMAKE | grep _decimal
printf "\n\n# ======================== regular ===========================\n\n"
@@ -163,7 +164,7 @@ for config in $CONFIGS; do
printf "\nbuilding python ...\n\n"
$GMAKE distclean > /dev/null 2>&1
- ./configure CFLAGS="$ADD_CFLAGS" --without-pymalloc $args > /dev/null 2>&1
+ ./configure CFLAGS="$ADD_CFLAGS" LDFLAGS="$ADD_LDFLAGS" --without-pymalloc $args > /dev/null 2>&1
$GMAKE | grep _decimal
printf "\n\n# ======================== valgrind ==========================\n\n"
@@ -9,8 +9,9 @@
# Requirements: valgrind
#
-# Set additional CFLAGS for ./configure
+# Set additional CFLAGS and LDFLAGS for ./configure
ADD_CFLAGS=